@@ -37,7 +37,7 @@ use File::Spec::Functions qw(catfile catpath splitpath);
 use Git::Repository;
 use TryCatch;
 
-use constant debstdversion => '4.7.0';
+use constant debstdversion => '4.7.2';
 
 our %DEFAULTS = (
 );
@@ -62,6 +62,11 @@ sub new {
     $self->control( Debian::Control->new )
         unless $self->control;
 
+    my @copyright;
+    tie @copyright, 'Array::Unique';
+
+    $self->copyright( \@copyright );
+
     return $self;
 }
 
@@ -204,7 +209,7 @@ sub extract_basic {
             } elsif ($line =~ /^;; Copyright /) {
                 chomp(my $copyright = $');
                 $copyright =~ s/  / /g;
-                $self->copyright($copyright);
+                push(@{$self->copyright}, $copyright);
             } elsif ($line =~ /either version 2/) {
                 $self->gpl_version("2");
             } elsif ($line =~ /either version 3/) {
@@ -458,22 +463,33 @@ sub create_watch {
 
     # try to take advantage of GitHub's release page, since mode=git
     # is much more taxing for QA team's servers
-    if ( $upstream_url =~ /github\.com\/([^\/]+)\/([^\/]+)(?:\.git)/ ||
-         $upstream_url =~ /github\.com\/([^\/]+)\/([^\/]+)/ ) {
-        my $user = $1;
+    if ( $upstream_url =~ m<github\.com/([^/]+)/([^/]+)> ||
+         $upstream_url =~ m<\@github\.com:([^/]+)/([^/+])> ) {
+        my $owner = $1;
         my $project = $2;
+        $project =~ s/.git\z//;
         $watch_file_content = <<EOT;
-version=4
-opts="filenamemangle=s/(?:.*?)?v?(\@ANY_VERSION\@\@ARCHIVE_EXT\@)/\@PACKAGE\@-\$1/" \\
-    https://github.com/$user/$project/tags \\
-    (?:.*?/)?\@ANY_VERSION\@\@ARCHIVE_EXT\@ debian uupdate
+Version: 5
+
+Template: Github
+Owner: $owner
+Project: $project
+EOT
+    } elsif ( $upstream_url =~ m<gitlab.com/([^/]+)/([^/]+)> ||
+              $upstream_url =~ m<\@gitlab.com:([^/]+)/([^/]+)> ) {
+        $watch_file_content = <<EOT;
+Version: 5
+
+Template: Gitlab
+Dist: $upstream_url
 EOT
     } else {
         $watch_file_content = <<EOT;
-version=4
-opts="mode=git" \\
-    $upstream_url \\
-    refs/tags/\@ANY_VERSION\@ debian
+Version: 5
+
+Source: $upstream_url
+Matching-Pattern: (?.*?/)?\@ANY_VERSION\@
+Mode: git
 EOT
     }
 
